pygeodesy.named._NamedEnumItem

Package pygeodesy :: Module named :: Class _NamedEnumItem |
[frames] | no frames]

# Class _NamedEnumItem

    object --+
             |
        _Named --+
                 |
        _NamedBase --+
                     |
                    _NamedEnumItem

Known Subclasses:
  - triaxials.bases._UnOrderedTriaxialBase
  - , lcc.Conic
  - , datums.Datum
  - , ellipsoids.Ellipsoid
  - , trf.RefFrame
  - , datums.Transform

(INTERNAL) Base class for items in a `_NamedEnum` registry.

Instance Methods
unregister(self) Remove this instance from its `_NamedEnum` registry. |
Inherited from `_NamedBase`: `__repr__`, `__str__`, `others`, `toRepr`, `toStr` Inherited from `_Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
| name Class `property` with a `.name` attribute.
Inherited from `_Named`: `classname`, `classnaming`, `iteration`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### unregister (self) |
Remove this instance from its `_NamedEnum` registry. Raises: `AssertionError` - Mismatch of this and registered item. `NameError` - This item is unregistered.

Property Details

### name Class `property` with a `.name` attribute. Get method: name(self) - Get the registered name (`str`). Set method: name(self, name) - Set the name, unless already registered (`str`).